<?php
include 'includes/db.php';
include 'includes/smtp.php';

$message = '';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $username = $_POST['username'];
    $email = $_POST['email'];
    $password = password_hash($_POST['password'], PASSWORD_BCRYPT);
    $verification_code = bin2hex(random_bytes(16));

    $stmt = $conn->prepare("INSERT INTO users (username, email, password, verification_code) VALUES (?, ?, ?, ?)");
    $stmt->bind_param('ssss', $username, $email, $password, $verification_code);

    if ($stmt->execute()) {
        $subject = "Email Verification";
        $verification_url = "http://localhost/demo/verify.php?code=$verification_code";
        $text = "Click the link to verify your email: <a href='$verification_url'>$verification_url</a>";
        
        if (send_verification_email($email, $subject, $text)) {
            $message = "Registration successful, please verify your email.";
        } else {
            $message = "Email sending failed.";
        }
    } else {
        $message = "Error: " . $stmt->error;
    }

    $stmt->close();
}

$conn->close();
?>
<!doctype html>
<html>
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100 flex items-center justify-center h-screen">
  <div class="bg-white p-6 rounded-lg shadow-lg max-w-lg">
    <?php if ($message): ?>
      <div class="mb-4 p-4 rounded-md max-w-md <?php echo $message === "Registration successful, please verify your email." ? 'bg-green-100 text-green-800' : 'bg-red-100 text-red-800'; ?>">
        <?php echo $message; ?>
      </div>
    <?php endif; ?>
    <form method="post" action="" class="flex flex-col w-full gap-2">
      <label>Username:</label>
      <input class="p-2 rounded-md bg-gray-100 border" type="text" name="username" required>
      
      <label>Email:</label>
      <input class="p-2 rounded-md bg-gray-100 border" type="email" name="email" required>
      
      <label>Password:</label>
      <input class="p-2 rounded-md bg-gray-100 border" type="password" name="password" required>
      
      <button class="px-3 py-2 rounded-md bg-green-500 text-white mt-2" type="submit">Register</button>
    </form>
    <a class="flex justify-center text-blue-500 mt-2 underline" href="login.php">Login</a>
  </div>
</body>
</html>
